from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x91\xdc\x06\x4a\xfb\x0e\x8e\xf0\x56\x2a\x71\x61\xf2\xef\xe4\x44\x00\x00\x00\x00\x00\x00\x00\x00\xe1\x8e\x8c\x00\x4f\x8d\xba\xc7\x46\x78\xfb\xd7\x27\x7e\xf5\xbf\x62\x36\x30\x66\x48\xca\xd2\x7d\x4c\x57\x1a\xd3\xab\x5e\x03\x80\x7a\x7a\xab\xec\x24\x4d\x04\xb5\xf2\xcb\x8c\x6d\x86\x80\x7d\x3c\x79\x7c\x1c\x5a\xf9\xe4\x33\xae\x08\x4f\x3d\xad\x25\xf0\x61\x2b\x51\x18\x4f\x59\xfa\xae\xc6\xfb\x98\x31\x8b\x08\x55\x0c\x74\xff\x66\x20\xf7\x2c\x55\xe5\xb4\x56\x02\xa1\x80\x6a\x6a\xeb\x8b\x3b\x28\x0d\x66\x04\x1e\xb3\x5c\x68\x9e\xcd\x62\x5e\xa1\x5f\x2d\x73\x4e\x07\xc2\x23\xb2\x45\x2b\x2c\x50\x0b\x22\xd4\xb4\xdc\x16\xd6\x30\x1f\x98\x79\x3e\xe3\xee\x5f\x47\xbb\xeb\xa8\x57\xb9\xea\x45\xc3\x28\xe2\xe7\x85\x3d\x8b\x72\xfa\xbb\x2d\x32\xb3\xf0\xca\x01\x7b\x7e\x5d\x50\x18\x13\x5a\x73\x81\x02\xe4\xac\x6e\x9b\x7e\xc1\x6b\x14\x0a\xf0\x86\xe7\x31\xf6\xee\xf7\x02\xcc\xee\x91\xb0\x00\x8d\xd1\xb8\xe2\x05\x05\x76\xfe\x2f\x63\x2a\x5a\x0c\x19\xf6\x10\xa7\x86\xb6\x53\xa8\xfa\xfa\x62\x8c\xb3\x6f\xc6\x7b\x96\x91\xd1\x46\x16\x1d\xd4\xaa\x60\xcb\xd7\x28\xeb\x36\x78\x77\xae\xe5\x0d\x38\x6a\x5e\x26\xe6\x41\x71\x4c\x82\xf4\xf9\x28\x75\x70\xf9\x03\xdc\xcb\x39\xfd\xfa\xca\xd1\x78\xbf\x5e\x29\xe7\xcc\xd7\x02\x8d\x6f\x23\xee\x0d\xfe\x7b\xc1\x03\xb9\x3a\x63\x86\xc1\x1a\x65\x9e\x4a\x3a\x74\x37\xc2\xc1\x75\x30\x6c\xe3\xe5\xc0\x2a\x31\x0b\xf7\xd2\x97\xc8\x34\x16\x35\xc7\x58\x07\x2c\xa1\xf1\x9f\x3e\x58\x7b\x34\x38\xd4\x2e\xaa\x06\x14\xac\x20\xcf\x36\x67\xf1\x14\x61\xe7\x33\x33\xc2\x33\xf6\xfc\x3a\x95\x1d\x34\x9c\x53\xc9\x18\x58\x84\x42\x4d\xdc\xef\x01\xd8\xae\xd5\xa6\x08\x29\xf5\x37\xd2\x3e\x12\xfc\x98\x3e\x2c\x08\x99\xb3\x60\xcb\xde\x05\x10\x4c\x9a\x38\x58\x5a\xb9\xa2\x00\xc0\xf1\x66\x6a\x3d\x32\xcf\x2d\x9e\xae\x53\xcb\x59\x79\x6a\xd3\x66\xd7\xc8\x58\x17\x27\x84\xec\xb7\x72\xa6\x3e\x4e\x05\x82\x4e\xf0\xa2\x41\x76\xa3\xd5\x26\x4f\xeb\x3a\xa7\x7a\x0c\xa2\x3a\x4d\x66\xee\x33\xfc\xa5\x34\xc6\x8d\x73\x35\xa7\xe3\x04\xae\xba\x84\x69\xc1\x23\x69\xb8\x8a\xd6\x30\x1d\x38\x4a\x67\x00\x0e\xe2\xea\xc0\x02\xef\xff\x99\xae\xf2\xce\x34\x4f\x57\xc0\x79\x17\xc2\xf9\x64\x10\x65\x97\xaa\xb2\x3f\xdd\x2c\x84\x96\xab\xac\x9f\x8f\xf5\x95\xbb\x62\x2a\xdd\x04\x71\x44\x64\x22\x30\xfe\xa3\xfa\x09\x3a\x57\xb3\xf6\xfd\x4a\xe4\xd2\xd4\xcf\x8a\xb3\x89\xcd\x23\xd8\x77\xfa\x40\x73\x5c\xdf\x28\xa7\x27\x79\xbf\x63\xa2\x14\x2b\x9a\x6d\xd5\x2f\x24\x97\x1b\xe6\xba\x72\xe2\x5a\xde\x68\x8b\xac\x29\xd3\xdd\x3d\xd9\xa2\x9a\xa2\x5d\x51\x32\x5e\x9f\xff\x6b\x48\xca\xad\xb5\x52\x81\x87\xa8\x78\x1d\xd8\x65\x3a\x7a\x3d\xd7\xe1\xf0\xab\xb1\x56\xb4\x34\x2c\xea\x39\x45\x98\x9a\x01\x48\xe7\xf7\x2c\xb1\x4b\x5d\xe4\xe0\xcb\xdc\x60\x03\xbc\x33\xb6\x81\x62\x1f\x2a\x70\x61\x0f\xaf\xcc\x1f\x87\x92\x9c\xd2\x9a\x88\xe4\x27\x7e\xb5\x8e\x88\xe3\x9b\xf5\xf5\x02\x64\x5b\xcd\xec\x03\x83\x0c\xc9\x2b\x66\x0f\x5b\xf8\x18\x1a\x3c\x14\xb2\x15\x14\x99\xe2\x4d\xca\xe9\x84\x16\xbd\xd5\x88\x00\xaa\xac\xc4\x03\x60\x4b\x3e\xb4\x19\x97\x53\x66\xf0\xe4\xfe\xa9\xec\xd7\x39\x63\xc5\x51\x0a\x5a\xf7\x92\x82\x66\xd9\x81\x5b\x21\xf3\x47\x9e\x5f\x21\xd0\x1c\x8e\x34\xcd\xad\xca\x50\xd5\x8d\xbe\xcf\xab\xe7\xff\x55\x6e\xad\x39\x6b\xef\x93\x9c\x66\x2a\x65\x95\x04\xe2\xe5\xef\x0f\x13\x64\x9c\x1e\x85\x6f\x81\xcc\x57\x4f\x81\xcd\x64\x1e\x3a\x80\x99\x63\xfa\x0c\x8a\x19\xd8\xc8\x64\x88\x44\xb9\xe0\xbc\xeb\xdf\xe0\xf6\xff\xc5\x53\x1b\x45\x22\x74\xc7\xc3\x1f\x82\x90\x05\x16\x94\x56\x20\x03\x68\x24\x01\x05\x75\xb1\x49\xf1\x78\x48\xbf\x7f\x24\x61\x7e\xa4\xc6\x67\xb0\x9b\x1b\xda\x36\x10\xd0\xaa\xb8\x9a\x60\xff\xca\x02\xc5\xfb\x2f\x38\xdf\xfc\x4f\xf1\x53\x4d\x77\xb1\xb3\x4d\x02\x42\xf7\x5f\x85\x28\x03\xf4\xda\xd3\x0f\x8d\xac\x84\x3e\x40\x9f\x57\x2c\x2c\x1d\x83\x27\xd6\x32\x2e\x30\x2f\x65\x4e\x81\x38\xb5\xda\xda\x57\x39\x67\xdc\x96\x99\x09\x9a\xbf\x49\x9f\xa1\xab\x43\x6d\xda\xe1\x84\x45\x90\x98\xc6\x76\x2a\xe8\xb4\x79\xfb\xb0\x3d\xd4\xac\x0a\x48\x0f\x17\xa6\x1f\x87\x9d\xd8\x3f\x55\x94\x82\x44\x85\xdc\x5a\xf5\x8b\x76\xbf\xe2\xca\x86\x9a\x88\xa0\x9c\x78\x00\x39\xb4\x5f\x92\x45\xb6\x87\x96\x36\x8a\xee\x97\x02\x84\xe5\x0a\x02\x7f\xc1\x8c\xf0\xc5\xd5\x1b\x1c\xb7\xe6\x6c\xd2\xc8\xed\xcd\x6a\x53\x98\xd1\x87\xe9\x53\x8b\xa6\x9d\xd1\xc3\x9f\x5d\x30\x22\x11\x0d\xed\x47\x31\xea\x12\x9e\x5a\x66\x93\x44\x4f\x4f\x30\x1c\xa7\xc8\x83\xff\xb9\xfb\x69\x5f\x87\x70\x7c\xcd\x61\x2a\xc6\x80\x71\xec\xb3\xbd\x0a\x13\xb9\x4b\xdb\x17\x28\x40\x71\xe3\x32\x56\x4d\x9a\x4d\xb8\x75\x3d\xfc\x08\x4c\xf2\x07\xe3\x6e\x65\xc5\xd6\x21\x27\x8c\xa1\xb3\x4c\x76\x7c\x87\x4e\x27\x0c\x06\xb8\x20\x3f\xab\x5b\xf4\xc5\x6a\x8b\x98\x15\x40\xe3\x88\x22\xd1\xd4\xf4\xcb\x53\x43\x67\xa2\xee\x12\xf3\x95\x76\x10\x6a\x1e\x13\x85\x51\xeb\xfa\x44\xac\xfa\x12\xff\xea\x67\x68\xc3\xb4\x75\xa8\xcf\x49\xc0\xa4\x9e\x87\xbf\xa6\xec\x06\x6a\x2f\x16\xda\x5b\xa4\xab\xd5\x72\x7d\x59\x8c\xa9\xf6\xc3\x41\xe0\xdf\x5d\x80\x7e\x18\x5a\xda\x24\x6a\x38\xab\xd3\xd2\xde\xe6\x88\xa3\x4d\x66\x5e\xd7\xf9\xab\xe7\x5e\xb4\xa0\x3e\xfb\xbf\xf7\x53\xb0\x00\xb7\xe6\x8a\xc6\xf3\x7a\x79\x49\x5b\x8e\xf1\x70\x0b\xf9\x93\x92\xc8\x71\xf0\x4f\xdb\xc6\x43\xce\x37\x75\xdd\x11\xcf\xf6\xa1\x3a\x95\x89\xa1\x59\x21\x3f\xd0\xf6\xfe\x9d\x32\xaa\x0c\x96\x77\xcb\x2b\x8e\x8b\x04\xa4\x5a\x21\xed\x38\xfc\x27\xbb\xeb\xa4\x3a\xef\x18\xab\xe7\x50\xf8\xe6\xc5\x90\xb1\xcc\xfa\x5d\x3a\x8c\xd0\x30\x83\xfa\x16\xae\x62\x27\x7e\xf8\x81\x51\x05\x25\xa0\xf5\xde\x8b\x12\x10\x27\x38\x0b\x2e\x9d\xd2\x81\x5e\x73\xc9\xd0\xd8\xb5\xd5\x74\x10\x36\xcb\x71\x75\x12\xce\x49\x9b\xd8\x6b\xda\x4a\xd1\xe1\x25\x8a\x0b\xec\xe1\x79\xfd\x7a\x38\xed\xa1\xde\x0f\xd3\xc5\x78\xfc\xc9\x2f\xee\xa1\x33\x64\x5a\x12\x35\xcb\x15\x53\x32\x3f\x73\x3f\xce\xe2\xe3\xe5\x35\xd0\xe3\x5f\x08\x1a\x67\x46\x54\xe9\x60\xf7\xc9\xdf\x61\xb2\x0f\x56\x73\x77\x2f\x8f\x03\xd2\x5a\xa5\x23\x3c\x2e\x5c\x50\x4b\x8e\x6e\xdc\x53\xfd\x35\xfc\x3e\xb3\xf4\xcc\xad\x52\xd8\xb9\xc5\x29\x68\x1d\x5e\xa4\x28\xcb\x1d\xed\x07\xf2\xd4\x31\x6d\x93\x74\x2a\xf0\xb0\x55\xb1\x25\x04\xfc\x45\xb6\xaa\xdb\xc0\x8f\x8b\xb9\x73\x0e\x2e\x8c\x5a\x11\xae\xd4\xd6\x79\x3e\x54\x16\xe5\x91\xdc\x42\xff\xd6\xd4\xba\xff\x59\x11\x67\xb6\x3e\x9d\x54\xc6\x86\x4a\x62\xa3\x54\xae\xa6\x10\x47\x43\x55\x1c\x73\x21\x42\x19\xc1\x2f\xe1\x87\x83\xec\xc2\x7e\x79\x54\x08\xc1\xc3\xba\x4a\x89\x08\xe1\x18\x9b\x73\xdd\x12\x12\x3d\x5e\xf3\x7a\x55\x38\x0a\xb3\x72\xa6\x63\x39\xc1\x0a\xdc\xf6\x39\x1d\xa6\x11\x97\x20\xbb\x07\x09\x9d\xcb\xe1\x50\x0e\xad\x48\x00\xdd\x78\x7f\x8d\xe8\xcd\x36\x00\x06\x53\x82\x42\x75\xf4\x5c\x26\xc5\x45\x64\xea\x9d\x08\x85\x27\xee\x45\xbf\x01\x72\x45\xe7\x91\x86\xed\x79\xf6\xd7\x33\x62\x48\xa4\x09\x0f\xed\x09\x09\x73\x2a\xcc\x91\x03\x5a\x6b\x8a\xcd\x78\xbe\x74\xe4\x4a\xb7\x41\x4d\x3d\xf4\x20\x24\x14\x51\xdc\x5c\xf8\x54\x1d\xda\x09\xaf\x9c\x0b\xc3\x24\x5f\xe7\x8e\x34\x05\xf9\x25\x6f\xc3\xe3\xc1\x00\x9d\x00\xe4\xbf\xef\x24\xf9\xe3\xa0\x0a\xd7\xe8\xea\xdf\xd8\x89\x67\x60\x6f\x01\xd6\x8d\x45\x26\xf6\x36\x88\xcc\xb9\xcf\xe7\x26\xd6\x0f\x27\xe9\x7b\x17\x43\xe2\x1e\xf3\x42\xce\xdb\x16\xe8\x9b\x70\xb8\x37\x21\x6e\xd8\x7d\xba\xc8\x02\x1f\xc0\x61\x12\x7f\x33\xab\xac\x33\xb5\x63\x68\x65\x63\xa2\x81\x55\xe5\x57\x04\x10\xcc\x59\x19\x97\xaa\x63\x07\x73\x63\x6d\x75\x5c\x14\xa9\x59\xb1\xa7\x42\xf7\xbd\x56\xce\xf2\x19\x39\x27\xd4\xf1\x7e\xbf\x78\x04\x36\xb7\x6d\xbd\x3a\x05\x6f\x35\xcc\x0f\xcc\x26\x24\x02\x62\x5c\x75\x38\x89\xf8\x79\xf2\x42\x4b\x55\x7f\x44\x00\x6a\xbf\x61\x3f\x39\xe9\x2e\xc3\x66\x61\x82\x8c\x89\xa5\x8d\x74\x08\xb3\xac\x93\x6a\xa5\x4d\xcb\x72\x34\x87\x46\x8b\x25\xbf\x43\xb8\x50\x83\xb1\x47\xba\x2c\xdf\x05\xb7\x1c\x3c\x07\x0d\xfd\x73\x2c\xff\xcb\xea\x91\xb4\xf6\x4c\x8a\x76\x30\xc3\xd5\xa0\x33\x3a\x86\x9d\xbf\xb7\x31\x1f\xe0\x59\x24\x73\x0a\x3a\x13\x10\xee\x44\x6e\x42\xcc\x92\xd1\x44\xae\xcd\x19\x9b\xad\xf3\x50\xcf\x82\xf4\x1e\x37\xe4\xde\x46\xc5\x4e\x96\xd8\x2c\x73\x24\x66\x52\x8f\xbe\x7a\x3b\xb1\x48\xd8\x73\x0a\x22\xef\x49\x7b\x44\xe8\x17\x3c\x2c\x02\x57\x13\x03\xf9\x45\xa8\x0b\x53\x23\x3b\x3b\x59\xec\x50\x3a\xbd\xb1\x86\x80\x3a\x47\x5f\x4f\x21\x00\xaf\x25\x6e\x9d\xfc\xbe\x00\x19\x84\xb4\x6f\x97\x54\x1c\x98\x13\x0e\x4a\x53\x14\x5b\xd0\x55\x96\xa1\x4b\xfc\xea\x21\x9b\x0c\x70\x26\xd7\xbc\x7a\x11\x04\xbc\xf7\xfd\x68\x1c\xf0\x0b\x93\xdd\x17\x2e\x00\x72\x15\x12\xd0\x42\xaa\x0d\xa9\xee\x2b\x92\x35\xb2\x8a\x10\xfa\xde\x61\xe6\xbf\x1b\xbb\x0e\x8d\xdd\x34\x72\x89\x7e\x6b\x55\x08\x93\x62\xa7\x2b\xc1\xfc\xe0\xeb\xcc\xd1\xd4\xe8\xbc\x60\x7e\x95\x57\x78\xd3\x9e\x11\x54\x86\x55\x70\x66\xa6\xfa\x1d\xae\x58\x1e\xdf\x4d\xba\x23\x41\x43\x8f\xff\x31\xbe\x25\x2c\x1b\xb7\x04\x85\x92\x9d\x7c\x05\x7e\xbd\x61\x46\xd9\xf7\x52\x28\x27\x74\x7a\xd7\xfd\x16\xc1\xce\xa6\xd8\x8d\xcc\x2f\xe3\xb0\xd4\x12\x9b\x7f\x85\x1c\x94\x6e\x8d\x30\x15\x44\xa9\xac\x99\x9e\x18\xde\x1c\x3c\x8a\xd9\x11\x38\xab\x5b\xed\x30\xd7\x33\xea\xa5\xe3\x8c\x79\xca\x6d\x71\xeb\x69\x8c\xde\x3b\xbe\x2c\xbd\x0d\xe0\x10\x47\x67\x69\x53\x66\xa6\x49\x4a\xea\x92\x6a\x5b\xc1\xbc\x71\xef\xf5\x7f\x51\xb5\xf5\xa0\x08\x81\x46\xd7\xa3\xee\x6a\xee\x39\x16\xa3\x5a\x5f\xbc\x4e\x72\x99\xe3\x89\xa4\x32\xa6\xb1\x94\xde\x1d\x77\xe3\x5b\x50\x49\x55\x41\x88\xff\x42\xb9\xcd\x61\x62\x93\x37\x10\x12\xfc\x8b\x37\xa0\xbc\x28\x91\x57\xea\x16\x4d\xc9\xeb\x69\x6b\x25\x0f\x6d', 2)

# cleanup
del pyarmor_runtime

